@@ -61,6 +61,7 @@ OptimizationMetricType = Literal["AverageWeightedQuantileLoss", "MAPE", "MASE",
 ScalingTypeType = Literal["Auto", "Linear", "Logarithmic", "ReverseLogarithmic"]
 ServiceName = Literal[
     "accessanalyzer",
+    "account",
     "acm",
     "acm-pca",
     "alexaforbusiness",
@@ -93,6 +94,7 @@ ServiceName = Literal[
     "chime-sdk-identity",
     "chime-sdk-messaging",
     "cloud9",
+    "cloudcontrol",
     "clouddirectory",
     "cloudformation",
     "cloudfront",
@@ -171,6 +173,7 @@ ServiceName = Literal[
     "glacier",
     "globalaccelerator",
     "glue",
+    "grafana",
     "greengrass",
     "greengrassv2",
     "groundstation",
